==> gtk%2B2-2.13.3-i486-1sys.tgz: usr/doc/gtk+2-2.13.3-i486-1sys/doinst.sh <==
#!/bin/sh
config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
config etc/gtk-2.0/im-multipress.conf.new

# Since the use of icon caching is optional, and has to be kept in sync
# somehow (like a "registry" through a cron job, or whatever) I tend to
# think the user should be the one to choose if they really want to set
# this up or not:
#
# Example:
#for dir in /usr/share/icons/* ; do
#  if [ -d $dir ]; then
#    /usr/bin/gtk-update-icon-cache -f -t $dir 1> /dev/null 2> /dev/null
#  fi
#done
mkdir -p etc/gtk-2.0

chroot . rm -f /usr/share/icons/*/icon-theme.cache 1> /dev/null 2> /dev/null

# This has a lot of X deps, so check for the obvious one first:
if [ -e usr/lib/libX11.so.6 ]; then
  chroot . usr/bin/gtk-query-immodules-2.0  > etc/gtk-2.0/gtk.immodules
# chroot . usr/bin/gdk-pixbuf-query-loaders > etc/gtk-2.0/gdk-pixbuf.loaders
fi
#
# Besser das auch nochmal unbedingt zu machen, so wie danach von den Programmen aufgerufen
#if [ -x /usr/bin/gdk-pixbuf-query-loaders ]; then
  /usr/bin/gdk-pixbuf-query-loaders > /etc/gtk-2.0/gdk-pixbuf.loaders 
#fi

#if [ -x gtk-query-immodules-2.0 ]; then
  /usr/bin/gtk-query-immodules-2.0 > /etc/gtk-2.0/gtk.immodules  
#fi

#if [ -x /usr/bin/gtk-update-icon-cache ]; then
  /usr/bin/gtk-update-icon-cache  -f -q /usr/share/icons 
#fi

==> gtk%2B2-2.13.7-i486-1sys.tgz: usr/doc/gtk+2-2.13.7-i486-1sys/doinst.sh <==
#!/bin/sh
config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
config etc/gtk-2.0/im-multipress.conf.new

# Since the use of icon caching is optional, and has to be kept in sync
# somehow (like a "registry" through a cron job, or whatever) I tend to
# think the user should be the one to choose if they really want to set
# this up or not:
#
# Example:
#for dir in /usr/share/icons/* ; do
#  if [ -d $dir ]; then
#    /usr/bin/gtk-update-icon-cache -f -t $dir 1> /dev/null 2> /dev/null
#  fi
#done
mkdir -p etc/gtk-2.0

chroot . rm -f /usr/share/icons/*/icon-theme.cache 1> /dev/null 2> /dev/null

# This has a lot of X deps, so check for the obvious one first:
if [ -e usr/lib/libX11.so.6 ]; then
  chroot . usr/bin/gtk-query-immodules-2.0  > etc/gtk-2.0/gtk.immodules
# chroot . usr/bin/gdk-pixbuf-query-loaders > etc/gtk-2.0/gdk-pixbuf.loaders
fi


#
# Besser das auch nochmal unbedingt zu machen, so wie danach von den Programmen aufgerufen
#if [ -x /usr/bin/gdk-pixbuf-query-loaders ]; then
#  /usr/bin/gdk-pixbuf-query-loaders > /etc/gtk-2.0/gdk-pixbuf.loaders 
#fi

#if [ -x gtk-query-immodules-2.0 ]; then
#  /usr/bin/gtk-query-immodules-2.0 > /etc/gtk-2.0/gtk.immodules  
#fi

#if [ -x /usr/bin/gtk-update-icon-cache ]; then
#  /usr/bin/gtk-update-icon-cache  -f -q  -t   /usr/share/icons   # /hicolor 
#fi
